@@ -689,9 +689,7 @@ rxCores <- getRxThreads
 #'   specified and `FALSE`, block a simple `rxUnloadAll()` will not
 #'   actually unload all dlls (helps with CRAN ASAN check)
 #'
-#' @return List of rxode2 dlls still loaded
-#'
-#' @return boolean of if all rxode2 dlls have been unloaded
+#' @return boolean telling if `rxUnloadAll()` completed the unloading procedure
 #'
 #' @examples
 #'
@@ -703,14 +701,84 @@ rxUnloadAll <- function(set=TRUE) {
     .rxUnloadAllEnv$reallyUnload <- TRUE
   }
   if (.rxUnloadAllEnv$reallyUnload  && isTRUE(set)) {
-    try(rxUnloadAll_(), silent = TRUE)
+    #try(rxUnloadAll_(), silent = TRUE)
   } else if (isTRUE(set)) {
     return(invisible(FALSE))
   } else if (isFALSE(set)) {
     .rxUnloadAllEnv$reallyUnload <- FALSE
     return(invisible(FALSE))
   }
-  try(rxUnloadAll_(), silent = TRUE)
+  # First slice down on the keep
+  .nKeep <- getOption("rxode2.dontUnload", 10)
+  .nKeep <- as.integer(.nKeep)
+  if (.nKeep <= 0L) {
+    .rxLastModels <- NULL
+  } else if (length(.rxLastModels) < .nKeep) {
+    .rxLastModels <- .rxLastModels[!is.na(.rxLastModels)]
+    .rxLastModels <- .rxLastModels[seq(1, .nKeep)]
+    assignInMyNamespace(".rxLastModels", .rxLastModels)
+  }
+  .ret <- try(rxUnloadAll_(), silent = TRUE)
+  # Now Look for orphan rxode2 DLLs
+  .loadedDLLs <- getLoadedDLLs()
+  .checkOrphans <- getOption("rxode2.checkOrphans", 75)
+  if (length(.loadedDLLs) >= .checkOrphans) {
+    .orphans <- character(0)
+    .n <- 0L
+    for (i in seq_along(.loadedDLLs)) {
+      .dll <- .loadedDLLs[[i]]
+      .name <- .dll[["name"]]
+      .path <- .dll[["path"]]
+      .mv <- paste0(.name, "_model_vars")
+
+      .mv <- try(eval(str2lang(paste0(".", "Call(", deparse1(.mv), ")")), envir=globalenv()), silent=TRUE)
+      if (!inherits(.mv, "try-error")) {
+        # This is a rxode2 DLL
+        .md5 <- .mv$md5["parsed_md5"]
+        if (.rxShouldUnload(.md5)) {
+          .n <- .n + 1L
+          # These are orphan models that should be unloaded
+          # unload
+          dyn.unload(.path)
+          # and remove information
+          .info <- .rxGetModelInfoFromDll(.path)
+          for (i in .info) {
+            .t <- try(exists(i, envir = .rxModels), silent=TRUE)
+            if (isTRUE(.t)) {
+              rm(list = i, envir = .rxModels)
+            } else if (inherits(.t, "try-error")) {
+              try(rm(list = i, envir = .rxModels), silent = TRUE)
+            }
+          }
+        } else {
+          # This is a model for consideration later
+          .orphans <- c(.orphans, .path)
+        }
+      }
+    }
+    .nKeep <- .nKeep - .n
+    if (length(.orphans) > .nKeep){
+      # If there are more orphans than the number of models to keep,
+      # then we will remove the last nKeep orphans
+      .orphans <- .orphans[-seq_len(.nKeep)]
+
+      for (o in .orphans) {
+        # Remove the orphan DLLs
+        dyn.unload(o)
+        # and remove information
+        .info <- .rxGetModelInfoFromDll(.path)
+        for (i in .info) {
+          .t <- try(exists(i, envir = .rxModels), silent=TRUE)
+          if (isTRUE(.t)) {
+            rm(list = i, envir = .rxModels)
+          } else if (inherits(.t, "try-error")) {
+            try(rm(list = i, envir = .rxModels), silent = TRUE)
+          }
+        }
+      }
+    }
+  }
+  invisible(TRUE)
 }
 #' With one sink, then release
 #'
