@@ -22,7 +22,7 @@ rxTest({
 
   tmp <- rxSolve(mod2, et)
 
-  plot(tmp, intestine)
+  vdiffr::expect_doppelganger("intestine-mod2a", plot(tmp, intestine))
 
   et <- #et(time=0, amt= 5, ss=1, ii=1, cmt=1) %>%
     et(time=0, cmt=1, amt=5, ii=4, ss=1) %>%
@@ -32,12 +32,12 @@ rxTest({
 
   tmp <- rxSolve(mod2, et)
 
-  plot(tmp, intestine)
+  vdiffr::expect_doppelganger("intestine-mod2b", plot(tmp, intestine))
 
   ms <- c("liblsoda", "lsoda", "dop853")
   for (m in ms) {
     skip_if_not_installed("units")
-    
+
     obs <- units::set_units(seq(0, 10, by = 1 / 24), "days")
 
     et <- eventTable(time.units = "days")
