@@ -22,16 +22,15 @@ rxTest({
 
     expect_equal(c("intestine", "blood"), rxState(mod))
 
-    expect_output(
-      expect_error(expect_message(rxode2({
-        a <- 6
-        b <- 0.6
-        cmt(matt) # cmt = 1 now
-        d/dt(intestine) <- -a * intestine
-        d/dt(blood) <- a * intestine - b * blood
-      }))),
-      regexp = "compartment 'matt' needs differential equations defined"
-    )
+    
+    expect_error(suppressMessages(rxode2({
+      a <- 6
+      b <- 0.6
+      cmt(matt) # cmt = 1 now
+      d/dt(intestine) <- -a * intestine
+      d/dt(blood) <- a * intestine - b * blood
+    })))
+      
 
     tmp <- rxode2({
       a <- 6
@@ -43,9 +42,11 @@ rxTest({
       d / dt(blood) <- a * intestine - b * blood
     })
     expect_equal(tmp$stateExtra, "matt")
+
   })
 
   test_that("Compartment melding with dvid", {
+
     w <- rxode2({
       ktr <- exp(tktr + eta.ktr)
       ka <- exp(tka + eta.ka)
@@ -74,8 +75,10 @@ rxTest({
       dvid(-1, 4)
     })
 
-    w2 <- warfarin
+    w2 <- nlmixr2data::warfarin
+
     tmp <- etTrans(w2, w, addCmt = TRUE)
+
     expect_equal(
       tmp$CMT[tmp$ID == 1],
       c(
@@ -111,8 +114,10 @@ rxTest({
       dvid(5, 4)
     })
 
-    w2 <- warfarin
+    w2 <- nlmixr2data::warfarin
+
     tmp <- etTrans(w2, w, addCmt = TRUE)
+
     expect_equal(
       tmp$CMT[tmp$ID == 1],
       c(
@@ -131,7 +136,7 @@ rxTest({
       )
     )
 
-    w2 <- warfarin
+    w2 <- nlmixr2data::warfarin
     w2$dvid <- as.integer(w2$dvid)
     tmp <- etTrans(w2, w, addCmt = TRUE)
     expect_equal(
@@ -142,7 +147,7 @@ rxTest({
       )
     )
 
-    w2 <- warfarin
+    w2 <- nlmixr2data::warfarin
     w2$dvid <- as.integer(w2$dvid) * 10
     expect_warning(tmp <- etTrans(w2, w, addCmt = TRUE))
     expect_equal(
@@ -180,7 +185,7 @@ rxTest({
       dvid(5)
     })
 
-    w2 <- warfarin
+    w2 <- nlmixr2data::warfarin
     w2$dvid <- as.integer(w2$dvid) * 10
     expect_warning(tmp <- etTrans(w2, w, addCmt = TRUE))
     expect_equal(
@@ -218,7 +223,7 @@ rxTest({
       dvid(4, 5)
     })
 
-    w2 <- warfarin
+    w2 <- nlmixr2data::warfarin
     w2$dvid <- as.integer(w2$dvid)
     tmp <- etTrans(w2, w, addCmt = TRUE)
     expect_equal(
@@ -384,7 +389,7 @@ rxTest({
 
     # context("warfarin inner test")
 
-    data.pkpd <- warfarin
+    data.pkpd <- nlmixr2data::warfarin
     data.pkpd$dvid <- as.integer(data.pkpd$dvid)
     data.pkpd$cmt <- paste(factor(data.pkpd$dvid, c(1, 2), c("center", "effect")))
     data.pkpd$cmt[data.pkpd$amt > 0] <- "depot"
