@@ -350,4 +350,38 @@ rxTest({
                              ev=dosing,
                              nDisplayProgress=100L), NA)
   })
+
+  test_that("iov curEval", {
+
+    one.cmt <- function() {
+      ini({
+        ## You may label each parameter with a comment
+        tka <- 0.45 # Log Ka
+        tcl <- log(c(0, 2.7, 100)) # Log Cl
+        ## This works with interactive models
+        ## You may also label the preceding line with label("label text")
+        tv <- 3.45; label("log V")
+        ## the label("Label name") works with all models
+        eta.ka ~ 0.6
+        eta.cl ~ 0.3
+        eta.v ~ 0.1
+        iov.cl ~ 0.1 | occ
+        add.sd <- 0.7
+      })
+      model({
+        ka <- exp(tka + eta.ka)
+        cl <- exp(tcl + eta.cl + iov.cl)
+        v <- exp(tv + eta.v)
+        linCmt() ~ add(add.sd)
+      })
+    }
+
+    f <- rxode2(one.cmt)
+
+    curEval <- f$muRefCurEval
+
+    expect_equal(curEval[curEval$parameter == "iov.cl", "curEval"],
+                 "exp")
+
+  })
 })
