@@ -10,22 +10,30 @@ rxTest({
       d/dt(eff)   <- Kin - Kout*(1-C2/(EC50+C2))*eff
     })
 
-    expect_error(assertRxUi(mod1), NA)
-    mod <-  assertRxUi(mod1)
+    suppressMessages(
+      expect_error(assertRxUi(mod1), NA)
+    )
+    suppressMessages(
+      mod <- assertRxUi(mod1)
+    )
     expect_true(inherits(mod, "rxUi"))
 
-    expect_error(mod1 %>% rxRename(C4=C2),NA)
-    mod <- mod1 %>% rxRename(C4=C2)
-    
+    suppressMessages(
+      expect_error(mod1 %>% rxRename(C4=C2), NA)
+    )
+    suppressMessages(
+      mod <- mod1 %>% rxRename(C4=C2)
+    )
     expect_true(inherits(mod, "rxUi"))
 
-    mod <- mod1 %>% ini(V2=1)
+    suppressMessages(
+      mod <- mod1 %>% ini(V2=1)
+    )
     expect_true(inherits(mod, "rxUi"))
 
-    mod <- mod1 %>% model(C2 <- centr)
-    
+    suppressMessages(
+      mod <- mod1 %>% model(C2 <- centr)
+    )
     expect_true(inherits(mod, "rxUi"))
-
   })
-
 })
